Swift skeleton code generator.
Generates Swift structs with Codable conformance for entities, enums with String raw values for union types, and throwing functions for actions.
Functions
- generate
- Generate Swift skeleton code from a parsed intent file.